/**
 * External dependencies
 */
const NpmApi = require('npm-api');
const npm = new NpmApi();

/**
 * Internal dependencies
 */
const CLIError = require( './cli-error' );
const prompts = require( './prompts' );

const slug = 'test';
const title = 'Create Block Plugin';
const namespace = 'create-block-plugin';
const dashicon = 'smiley';
const category = 'common';
const author = 'blockhandbook';
const license = 'GPL-2.0-or-later';
const licenseURI = 'https://www.gnu.org/licenses/gpl-2.0.html';
const authorURI = 'https://blockhandbook.com/';
const authorEmail = 'yourname@yourwebsite.com';
const pluginURI = 'https://wordpress.org/plugins/';
const version = '1.0.0';
const port = 8888;
const testsPort = 8889;
const git = false;
const server = false;
const cssFramework = 'None';

const templates = {
	default: {
		defaultValues: {
			namespace,
			slug,
			title,
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: true,
			register_block_patterns: true,
			register_blocks: true,
			register_testimonial_custom_post_type: true,
			register_team_custom_post_type: true,
			register_plugin_settings: true,
			register_rest_api: true,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: true,
			registerFilters: true,
			registerFormats: true,
			registerStores: true,
			registerVariations: true,
			registerFrontend: true,
			softwareLicensing: true,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/block-patterns/hero.php',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/PluginUpdater.php',
			'includes/RegisterBlockPatterns.php',
			'includes/RegisterBlocks.php',
			'includes/RegisterTeamCustomPostType.php',
			'includes/RegisterTestimonialCustomPostType.php',
			'includes/RegisterPluginSettings.php',
			'includes/RegisterRestApi.php',
			'includes/SoftwareLicensing.php',
			'src/blocks/testimonial-custom-post-type-block/block.json',
			'src/blocks/testimonial-custom-post-type-block/controls.js',
			'src/blocks/testimonial-custom-post-type-block/deprecated.js',
			'src/blocks/testimonial-custom-post-type-block/edit.js',
			'src/blocks/testimonial-custom-post-type-block/index.scss',
			'src/blocks/testimonial-custom-post-type-block/icons.js',
			'src/blocks/testimonial-custom-post-type-block/index.js',
			'src/blocks/testimonial-custom-post-type-block/save.js',
			'src/blocks/testimonial-custom-post-type-block/style.scss',
			'src/blocks/testimonial-custom-post-type-block/transforms.js',
			'src/blocks/dynamic-block/block.json',
			'src/blocks/dynamic-block/DynamicBlock.php',
			'src/blocks/dynamic-block/controls.js',
			'src/blocks/dynamic-block/deprecated.js',
			'src/blocks/dynamic-block/edit.js',
			'src/blocks/dynamic-block/index.scss',
			'src/blocks/dynamic-block/icons.js',
			'src/blocks/dynamic-block/index.js',
			'src/blocks/dynamic-block/style.scss',
			'src/blocks/dynamic-block/transforms.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/block.json',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/DynamicTestimonialCustomPostTypeWithMetaBlock.php',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/controls.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/deprecated.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/edit.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/index.scss',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/icons.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/index.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/style.scss',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/transforms.js',
			'src/blocks/dynamic-team-custom-post-type-block/block.json',
			'src/blocks/dynamic-team-custom-post-type-block/DynamicTeamCustomPostTypeBlock.php',
			'src/blocks/dynamic-team-custom-post-type-block/controls.js',
			'src/blocks/dynamic-team-custom-post-type-block/deprecated.js',
			'src/blocks/dynamic-team-custom-post-type-block/edit.js',
			'src/blocks/dynamic-team-custom-post-type-block/index.scss',
			'src/blocks/dynamic-team-custom-post-type-block/icons.js',
			'src/blocks/dynamic-team-custom-post-type-block/index.js',
			'src/blocks/dynamic-team-custom-post-type-block/style.scss',
			'src/blocks/dynamic-team-custom-post-type-block/transforms.js',
			'src/blocks/frontend-block/block.json',
			'src/blocks/frontend-block/controls.js',
			'src/blocks/frontend-block/deprecated.js',
			'src/blocks/frontend-block/edit.js',
			'src/blocks/frontend-block/index.scss',
			'src/blocks/frontend-block/frontend.js',
			'src/blocks/frontend-block/icons.js',
			'src/blocks/frontend-block/index.js',
			'src/blocks/frontend-block/save.js',
			'src/blocks/frontend-block/style.scss',
			'src/blocks/frontend-block/transforms.js',
			'src/blocks/inner-block/block.json',
			'src/blocks/inner-block/controls.js',
			'src/blocks/inner-block/deprecated.js',
			'src/blocks/inner-block/edit.js',
			'src/blocks/inner-block/index.scss',
			'src/blocks/inner-block/icons.js',
			'src/blocks/inner-block/index.js',
			'src/blocks/inner-block/save.js',
			'src/blocks/inner-block/style.scss',
			'src/blocks/inner-block/transforms.js',
			'src/blocks/inner-block-with-variations/block.json',
			'src/blocks/inner-block-with-variations/controls.js',
			'src/blocks/inner-block-with-variations/deprecated.js',
			'src/blocks/inner-block-with-variations/edit.js',
			'src/blocks/inner-block-with-variations/index.scss',
			'src/blocks/inner-block-with-variations/icons.js',
			'src/blocks/inner-block-with-variations/index.js',
			'src/blocks/inner-block-with-variations/save.js',
			'src/blocks/inner-block-with-variations/style.scss',
			'src/blocks/inner-block-with-variations/transforms.js',
			'src/blocks/inner-block-with-variations/variations.js',
			'src/blocks/rich-text-block/block.json',
			'src/blocks/rich-text-block/controls.js',
			'src/blocks/rich-text-block/deprecated.js',
			'src/blocks/rich-text-block/edit.js',
			'src/blocks/rich-text-block/index.scss',
			'src/blocks/rich-text-block/icons.js',
			'src/blocks/rich-text-block/index.js',
			'src/blocks/rich-text-block/save.js',
			'src/blocks/rich-text-block/style.scss',
			'src/blocks/rich-text-block/transforms.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/block.json',
			'src/blocks/rich-text-block-with-plugin-sidebar/controls.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/deprecated.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/edit.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/index.scss',
			'src/blocks/rich-text-block-with-plugin-sidebar/icons.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/index.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/save.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/style.scss',
			'src/blocks/rich-text-block-with-plugin-sidebar/transforms.js',
			'src/blocks/rich-text-block-with-deprecated/block.json',
			'src/blocks/rich-text-block-with-deprecated/controls.js',
			'src/blocks/rich-text-block-with-deprecated/deprecated.js',
			'src/blocks/rich-text-block-with-deprecated/edit.js',
			'src/blocks/rich-text-block-with-deprecated/index.scss',
			'src/blocks/rich-text-block-with-deprecated/icons.js',
			'src/blocks/rich-text-block-with-deprecated/index.js',
			'src/blocks/rich-text-block-with-deprecated/save.js',
			'src/blocks/rich-text-block-with-deprecated/style.scss',
			'src/blocks/rich-text-block-with-deprecated/transforms.js',
			'src/blocks/rich-text-block-with-transforms/block.json',
			'src/blocks/rich-text-block-with-transforms/controls.js',
			'src/blocks/rich-text-block-with-transforms/deprecated.js',
			'src/blocks/rich-text-block-with-transforms/edit.js',
			'src/blocks/rich-text-block-with-transforms/index.scss',
			'src/blocks/rich-text-block-with-transforms/icons.js',
			'src/blocks/rich-text-block-with-transforms/index.js',
			'src/blocks/rich-text-block-with-transforms/save.js',
			'src/blocks/rich-text-block-with-transforms/style.scss',
			'src/blocks/rich-text-block-with-transforms/transforms.js',
			'src/blocks/static-block/block.json',
			'src/blocks/static-block/controls.js',
			'src/blocks/static-block/deprecated.js',
			'src/blocks/static-block/edit.js',
			'src/blocks/static-block/index.scss',
			'src/blocks/static-block/icons.js',
			'src/blocks/static-block/index.js',
			'src/blocks/static-block/save.js',
			'src/blocks/static-block/style.scss',
			'src/blocks/static-block/transforms.js',
			'src/blocks/static-block-with-styles/block.json',
			'src/blocks/static-block-with-styles/controls.js',
			'src/blocks/static-block-with-styles/deprecated.js',
			'src/blocks/static-block-with-styles/edit.js',
			'src/blocks/static-block-with-styles/index.scss',
			'src/blocks/static-block-with-styles/icons.js',
			'src/blocks/static-block-with-styles/index.js',
			'src/blocks/static-block-with-styles/save.js',
			'src/blocks/static-block-with-styles/style.scss',
			'src/blocks/static-block-with-styles/transforms.js',
			'src/components/software-licensing/index.js',
			'src/components/software-licensing/index.scss',
			'src/components/welcome-guide/index.js',
			'src/filters/add-padding-controls-to-group-block/index.js',
			'src/filters/add-padding-controls-to-group-block/style.scss',
			'src/filters/add-padding-controls-to-group-block/index.scss',
			'src/formats/uppercase/edit.js',
			'src/formats/uppercase/icon.js',
			'src/formats/uppercase/index.js',
			'src/formats/uppercase/style.scss',
			'src/plugins/plugin-settings/index.js',
			'src/plugins/plugin-settings/icons.js',
			'src/stores/plugin-settings/index.js',
			'src/utils/helpers.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/frontend.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	richTextBlock: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/rich-text-block/block.json',
			'src/blocks/rich-text-block/controls.js',
			'src/blocks/rich-text-block/deprecated.js',
			'src/blocks/rich-text-block/edit.js',
			'src/blocks/rich-text-block/index.scss',
			'src/blocks/rich-text-block/icons.js',
			'src/blocks/rich-text-block/index.js',
			'src/blocks/rich-text-block/save.js',
			'src/blocks/rich-text-block/style.scss',
			'src/blocks/rich-text-block/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	richTextBlockWithDeprecated: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/rich-text-block-with-deprecated/block.json',
			'src/blocks/rich-text-block-with-deprecated/controls.js',
			'src/blocks/rich-text-block-with-deprecated/deprecated.js',
			'src/blocks/rich-text-block-with-deprecated/edit.js',
			'src/blocks/rich-text-block-with-deprecated/index.scss',
			'src/blocks/rich-text-block-with-deprecated/icons.js',
			'src/blocks/rich-text-block-with-deprecated/index.js',
			'src/blocks/rich-text-block-with-deprecated/save.js',
			'src/blocks/rich-text-block-with-deprecated/style.scss',
			'src/blocks/rich-text-block-with-deprecated/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	richTextBlockWithPluginSidebar: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: true,
			register_rest_api: true,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: true,
			registerFilters: false,
			registerFormats: false,
			registerStores: true,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/LoadTranslations.php',
			'includes/EnqueueAssets.php',
			'includes/RegisterBlocks.php',
			'includes/RegisterPluginSettings.php',
			'includes/RegisterRestApi.php',
			'src/blocks/rich-text-block-with-plugin-sidebar/block.json',
			'src/blocks/rich-text-block-with-plugin-sidebar/controls.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/deprecated.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/edit.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/index.scss',
			'src/blocks/rich-text-block-with-plugin-sidebar/icons.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/index.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/save.js',
			'src/blocks/rich-text-block-with-plugin-sidebar/style.scss',
			'src/blocks/rich-text-block-with-plugin-sidebar/transforms.js',
			'src/components/welcome-guide/index.js',
			'src/plugins/plugin-settings/index.js',
			'src/plugins/plugin-settings/icons.js',
			'src/stores/plugin-settings/index.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	richTextBlockWithTransforms: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/rich-text-block-with-transforms/block.json',
			'src/blocks/rich-text-block-with-transforms/controls.js',
			'src/blocks/rich-text-block-with-transforms/deprecated.js',
			'src/blocks/rich-text-block-with-transforms/edit.js',
			'src/blocks/rich-text-block-with-transforms/index.scss',
			'src/blocks/rich-text-block-with-transforms/icons.js',
			'src/blocks/rich-text-block-with-transforms/index.js',
			'src/blocks/rich-text-block-with-transforms/save.js',
			'src/blocks/rich-text-block-with-transforms/style.scss',
			'src/blocks/rich-text-block-with-transforms/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	innerBlock: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			registerCategories: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/inner-block/block.json',
			'src/blocks/inner-block/controls.js',
			'src/blocks/inner-block/deprecated.js',
			'src/blocks/inner-block/edit.js',
			'src/blocks/inner-block/index.scss',
			'src/blocks/inner-block/icons.js',
			'src/blocks/inner-block/index.js',
			'src/blocks/inner-block/save.js',
			'src/blocks/inner-block/style.scss',
			'src/blocks/inner-block/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	innerBlockWithVariations: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: true,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/inner-block-with-variations/block.json',
			'src/blocks/inner-block-with-variations/controls.js',
			'src/blocks/inner-block-with-variations/deprecated.js',
			'src/blocks/inner-block-with-variations/edit.js',
			'src/blocks/inner-block-with-variations/index.scss',
			'src/blocks/inner-block-with-variations/icons.js',
			'src/blocks/inner-block-with-variations/index.js',
			'src/blocks/inner-block-with-variations/save.js',
			'src/blocks/inner-block-with-variations/style.scss',
			'src/blocks/inner-block-with-variations/transforms.js',
			'src/blocks/inner-block-with-variations/variations.js',
			'src/utils/helpers.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	frontendBlock: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: true,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/LoadTranslations.php',
			'includes/EnqueueAssets.php',
			'includes/RegisterBlocks.php',
			'src/blocks/frontend-block/block.json',
			'src/blocks/frontend-block/controls.js',
			'src/blocks/frontend-block/deprecated.js',
			'src/blocks/frontend-block/edit.js',
			'src/blocks/frontend-block/index.scss',
			'src/blocks/frontend-block/frontend.js',
			'src/blocks/frontend-block/icons.js',
			'src/blocks/frontend-block/index.js',
			'src/blocks/frontend-block/save.js',
			'src/blocks/frontend-block/style.scss',
			'src/blocks/frontend-block/transforms.js',
			'src/utils/helpers.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/frontend.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	dynamicBlock: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: true,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/dynamic-block/block.json',
			'src/blocks/dynamic-block/DynamicBlock.php',
			'src/blocks/dynamic-block/controls.js',
			'src/blocks/dynamic-block/deprecated.js',
			'src/blocks/dynamic-block/edit.js',
			'src/blocks/dynamic-block/index.scss',
			'src/blocks/dynamic-block/icons.js',
			'src/blocks/dynamic-block/index.js',
			'src/blocks/dynamic-block/style.scss',
			'src/blocks/dynamic-block/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	dynamicTeamCustomPostTypeBlock: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: true,
			register_block_patterns: false,
			register_blocks: true,
			register_testimonial_custom_post_type: false,
			register_team_custom_post_type: true,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'includes/RegisterTeamCustomPostType.php',
			'src/blocks/dynamic-team-custom-post-type-block/block.json',
			'src/blocks/dynamic-team-custom-post-type-block/DynamicTeamCustomPostTypeBlock.php',
			'src/blocks/dynamic-team-custom-post-type-block/controls.js',
			'src/blocks/dynamic-team-custom-post-type-block/deprecated.js',
			'src/blocks/dynamic-team-custom-post-type-block/edit.js',
			'src/blocks/dynamic-team-custom-post-type-block/index.scss',
			'src/blocks/dynamic-team-custom-post-type-block/icons.js',
			'src/blocks/dynamic-team-custom-post-type-block/index.js',
			'src/blocks/dynamic-team-custom-post-type-block/style.scss',
			'src/blocks/dynamic-team-custom-post-type-block/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	dynamicTestimonialCustomPostTypeWithMetaBlock: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: true,
			register_block_patterns: false,
			register_blocks: true,
			register_testimonial_custom_post_type: true,
			register_team_custom_post_type: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/LoadTranslations.php',
			'includes/EnqueueAssets.php',
			'includes/RegisterBlocks.php',
			'includes/RegisterTestimonialCustomPostType.php',
			'src/blocks/testimonial-custom-post-type-block/block.json',
			'src/blocks/testimonial-custom-post-type-block/controls.js',
			'src/blocks/testimonial-custom-post-type-block/deprecated.js',
			'src/blocks/testimonial-custom-post-type-block/edit.js',
			'src/blocks/testimonial-custom-post-type-block/index.scss',
			'src/blocks/testimonial-custom-post-type-block/icons.js',
			'src/blocks/testimonial-custom-post-type-block/index.js',
			'src/blocks/testimonial-custom-post-type-block/save.js',
			'src/blocks/testimonial-custom-post-type-block/style.scss',
			'src/blocks/testimonial-custom-post-type-block/transforms.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/block.json',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/DynamicTestimonialCustomPostTypeWithMetaBlock.php',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/controls.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/deprecated.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/edit.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/index.scss',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/icons.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/index.js',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/style.scss',
			'src/blocks/dynamic-testimonial-custom-post-type-with-meta-block/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	blockPattern: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: true,
			register_blocks: false,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: false,
			registerCategories: false,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/block-patterns/hero.php',
			'includes/LoadTranslations.php',
			'includes/EnqueueAssets.php',
			'includes/RegisterBlockPatterns.php',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	format: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: false,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: false,
			registerCategories: false,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: true,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/LoadTranslations.php',
			'includes/EnqueueAssets.php',
			'src/formats/uppercase/edit.js',
			'src/formats/uppercase/icon.js',
			'src/formats/uppercase/index.js',
			'src/formats/uppercase/style.scss',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	filter: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: false,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: true,
			registerBlocks: false,
			registerCategories: false,
			registerPlugins: false,
			registerFilters: true,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterRestApi.php',
			'src/filters/add-padding-controls-to-group-block/index.js',
			'src/filters/add-padding-controls-to-group-block/style.scss',
			'src/filters/add-padding-controls-to-group-block/index.scss',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	staticBlock: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/static-block/block.json',
			'src/blocks/static-block/controls.js',
			'src/blocks/static-block/deprecated.js',
			'src/blocks/static-block/edit.js',
			'src/blocks/static-block/index.scss',
			'src/blocks/static-block/icons.js',
			'src/blocks/static-block/index.js',
			'src/blocks/static-block/save.js',
			'src/blocks/static-block/style.scss',
			'src/blocks/static-block/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	staticBlockWithStyles: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: true,
			register_custom_post_types: false,
			register_plugin_settings: false,
			register_rest_api: false,
			registerBlocks: true,
			registerCategories: true,
			registerPlugins: false,
			registerFilters: false,
			registerFormats: false,
			registerStores: false,
			registerVariations: false,
			registerFrontend: false,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/EnqueueAssets.php',
			'includes/LoadTranslations.php',
			'includes/RegisterBlocks.php',
			'src/blocks/static-block-with-styles/block.json',
			'src/blocks/static-block-with-styles/controls.js',
			'src/blocks/static-block-with-styles/deprecated.js',
			'src/blocks/static-block-with-styles/edit.js',
			'src/blocks/static-block-with-styles/index.scss',
			'src/blocks/static-block-with-styles/icons.js',
			'src/blocks/static-block-with-styles/index.js',
			'src/blocks/static-block-with-styles/save.js',
			'src/blocks/static-block-with-styles/style.scss',
			'src/blocks/static-block-with-styles/transforms.js',
			'src/utils/icons.js',
			'src/utils/register-categories.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
	softwareLicensing: {
		defaultValues: {
			namespace,
			slug: 'test',
			title: 'Create Block Plugin',
			description:
				'Block Editor plugin generated by create-block-plugin – build step required.',
			dashicon,
			category,
			author,
			authorEmail,
			license,
			licenseURI,
			authorURI,
			pluginURI,
			version,
			port,
			testsPort,
			git,
			server,
			cssFramework,
			load_dynamic_blocks: false,
			register_block_patterns: false,
			register_blocks: false,
			register_custom_post_types: false,
			register_plugin_settings: true,
			register_rest_api: true,
			registerBlocks: false,
			registerCategories: true,
			registerPlugins: true,
			registerFilters: false,
			registerFormats: false,
			registerStores: true,
			registerVariations: false,
			registerFrontend: false,
			softwareLicensing: true,
		},
		outputFiles: [
			'.wordpress-org/banner-772x250.png',
			'.wordpress-org/banner-1544x500.png',
			'.wordpress-org/icon-128x128.png',
			'.wordpress-org/icon-256x256.png',
			'.wordpress-org/screenshot-1.png',
			'.github/workflows/assets.yml',
			'.github/workflows/release.yml',
			'includes/LoadTranslations.php',
			'includes/EnqueueAssets.php',
			'includes/PluginUpdater.php',
			'includes/RegisterPluginSettings.php',
			'includes/RegisterRestApi.php',
			'includes/SoftwareLicensing.php',
			'src/components/software-licensing/index.js',
			'src/components/software-licensing/index.scss',
			'src/components/welcome-guide/index.js',
			'src/plugins/plugin-settings/index.js',
			'src/plugins/plugin-settings/icons.js',
			'src/stores/plugin-settings/index.js',
			'src/index.js',
			'src/index.scss',
			'src/style.scss',
			'src/bootstrap.scss',
			'src/tailwind.css',
			'.distignore',
			'.editorconfig',
			'.gitignore',
			'.htaccess',
			'.wp-env.json',
			'bs-config.js',
			'Plugin.php',
			'composer.json',
			'LICENSE',
			'package.json',
			'postcss.config.js',
			'readme.txt',
			'tailwind.config.js',
			'webpack.config.js',
		],
	},
};

const getTemplate = ( templateName ) => {
	if ( ! templates[ templateName ] ) {
		throw new CLIError(
			`Invalid template type name. Allowed values: ${ Object.keys(
				templates
			).join( ', ' ) }.`
		);
	}
	return templates[ templateName ];
};

const getDefaultValues = ( templateName ) => {
	return getTemplate( templateName ).defaultValues;
};

const getOutputFiles = ( templateName ) => {
	return getTemplate( templateName ).outputFiles;
};

const getPrompts = ( templateName ) => {
	const defaultValues = getDefaultValues( templateName );
	return Object.keys( prompts ).map( ( promptName ) => {
		return {
			...prompts[ promptName ],
			default: defaultValues[ promptName ],
		};
	} );
};

const getVersions = async ( dependencies ) => {

	let versions = {};

	for( let i = 0; i < dependencies.length; i++ ) {

		const repo = npm.repo( dependencies[i] );
		const version = repo.package()
			.then(function(pkg) {
				return pkg.version;
			}, function(err) {
				console.error(err);
			});

		versions = {
			...versions,
			[ dependencies[i] ]: await version,
		}
	}

	return versions;
};

module.exports = {
	getDefaultValues,
	getOutputFiles,
	getPrompts,
	getVersions
};
